==> persistent_url_parameters-7.x-2.6.tar.gz: persistent_url_parameters/js/persistent_url_parameters.js <==
/**
 * @file
 * Implements javascript to retain url parameters based on conditions.
 */
(function ($) {

  'use strict';

  Drupal.behaviors.persistent_url_parameters = {
    attach: function (context, settings) {
      var querystring = window.location.href.slice(window.location.href.indexOf('?') + 1);
      querystring = decodeURI(querystring);
      var list = Drupal.settings.persistent_url_parameters.list;
      list = list.split('|');
      var is_present = false;
      list.forEach(function (entry) {
        if (querystring.toLowerCase().match(entry + '=')) {
          is_present = true;
        }
      });

      if (is_present) {

        // Store parameters in cookie coming directly from campaign urls
        // to avoid additional parameters on a subsequent page request.
        var parameters_in_cookie = $.cookie('persistent_url_parameters');
		if(typeof parameters_in_cookie === 'undefined'){
		  $.cookie('persistent_url_parameters', querystring, {
            path: '/',
            expires: 7
          });
		}
        else if(typeof parameters_in_cookie !== 'undefined' && !querystring.match(parameters_in_cookie)) {
          $.cookie('persistent_url_parameters', querystring, {
            path: '/',
            expires: 7
          });
        }
        else {
          querystring = parameters_in_cookie;
        }

        $('a').each(function (event) {
          // If anchor tag already processed.
          if ($(this).hasClass('link-string-processed')) {
            return false;
          }

          var href = $(this).attr('href');
          var target = $(this).attr('target');

          // Check for invalid urls. Replaced javascript:void(0) to  event.preventDefault()
          if (href && (!target || target !== '_blank') && (href !== "javascript:void(0)") && (href !== '#')) {

            // Avoid anchor tag starting with hash
            if (typeof href !== 'undefined' && href.match('^#') !== 'undefined' && href.match('^#') === null) {

              // If anchor tag contains parameters.
              if (href.match(/\?/)) {

                // Check for parameterized urls.
                var anchor_params = href.slice(href.indexOf('?') + 1);
                var anchor_path = href.slice(0, href.indexOf('?'));

                // Reconstruct url based on hash found on anchor tag.
                if (anchor_params.match('#')) {
                  var anchor_params_without_hash = anchor_params.slice(0, anchor_params.indexOf('#'));
                  var anchor_hash = anchor_params.slice(anchor_params.indexOf('#'));

                  // If anchor parameters matches with query parameters.
                  if (anchor_params_without_hash.match(querystring)) {
                    href = anchor_path + '?' + querystring;
                  }
                  else {
                    href = anchor_path + '?' + anchor_params_without_hash + '&' + querystring + anchor_hash;
                  }
                }
                else {
                  // If anchor parameters matches with query parameters.
                  if (anchor_params.match(querystring)) {
                    href = anchor_path + '?' + querystring;
                  }
                  else {
                    href += '&' + querystring;
                  }
                }
              }
              else {
                // Anchor tag doesn't contains parameters.
                href += '?' + querystring;
              }
              $(this).attr('href', encodeURI(href));
              $(this).addClass('link-string-processed');
            }
          }
        });
      }
    }
  };
})(jQuery);

==> persistent_url_parameters-7.x-3.2.tar.gz: persistent_url_parameters/js/persistent_url_parameters.js <==
/**
 * @file
 * Implements javascript to retain url parameters based on conditions.
 */
(function ($) {

  'use strict';

  Drupal.behaviors.persistent_url_parameters = {
    attach: function (context, settings) {
      var querystring = window.location.href.slice(window.location.href.indexOf('?') + 1);
      querystring = decodeURI(querystring);
      var list = Drupal.settings.persistent_url_parameters.list;
      list = list.split('|');
      var is_present = false;
      list.forEach(function (entry) {
        if (querystring.toLowerCase().match(entry + '=')) {
          is_present = true;
        }
      });

      if (is_present) {

        // Store parameters in cookie coming directly from campaign urls
        // to avoid additional parameters on a subsequent page request.
        var parameters_in_cookie = $.cookie('persistent_url_parameters');

        if(typeof parameters_in_cookie === 'undefined'){
          $.cookie('persistent_url_parameters', querystring, {
            path: '/',
            expires: 1
          });
        }
        else if(typeof parameters_in_cookie !== 'undefined' && !(querystring.match(parameters_in_cookie) && querystring.length === parameters_in_cookie.length)) {
          $.cookie('persistent_url_parameters', querystring, {
            path: '/',
            expires: 1
          });
        }
        else {
          querystring = parameters_in_cookie;
        }

        $('a').each(function (event) {
          // If anchor tag already processed.
          if ($(this).hasClass('link-string-processed')) {
            return false;
          }

          var href = $(this).attr('href');
          var target = $(this).attr('target');

          // Check for invalid urls. Replaced javascript:void(0) to  event.preventDefault()
          if (href && (!target || target !== '_blank') && (href !== "javascript:void(0)") && (href !== '#')) {

            // Avoid anchor tag starting with hash
            if (typeof href !== 'undefined' && href.match('^#') !== 'undefined' && href.match('^#') === null) {

              // If anchor tag contains parameters.
              if (href.match(/\?/)) {

                // Check for parameterized urls.
                var anchor_params = href.slice(href.indexOf('?') + 1);
                var anchor_path = href.slice(0, href.indexOf('?'));

                // Reconstruct url based on hash found on anchor tag.
                if (anchor_params.match('#')) {
                  var anchor_params_without_hash = anchor_params.slice(0, anchor_params.indexOf('#'));
                  var anchor_hash = anchor_params.slice(anchor_params.indexOf('#'));

                  // If anchor parameters matches with query parameters.
                  if (anchor_params_without_hash.match(querystring)) {
                    href = anchor_path + '?' + anchor_params_without_hash;
                  }
                  else {
                    href = anchor_path + '?' + anchor_params_without_hash + '&' + querystring + anchor_hash;
                  }
                }
                else {
                  // If anchor parameters matches with query parameters.
                  if (anchor_params.match(querystring)) {
                    href = anchor_path + '?' + anchor_params;
                  }
                  else {
                    href += '&' + querystring;
                  }
                }
              }
              else {
                // Anchor tag doesn't contains parameters.
                href += '?' + querystring;
              }
              $(this).attr('href', encodeURI(href));
              $(this).addClass('link-string-processed');
            }
          }
        });
      }
    }
  };
})(jQuery);
